@@ -5,7 +5,7 @@ from drf_yasg.inspectors.base import NotHandled
 from drf_yasg.inspectors.field import FieldInspector, InlineSerializerInspector
 from rest_framework import serializers
 
-from ..serializers import GegevensGroepSerializer
+from ..serializers import GegevensGroepSerializer, LengthHyperlinkedRelatedField
 
 logger = logging.getLogger(__name__)
 
@@ -98,6 +98,31 @@ class HyperlinkedIdentityFieldInspector(FieldInspector):
         return NotHandled
 
 
+class HyperlinkedRelatedFieldInspector(FieldInspector):
+    def field_to_swagger_object(
+        self, field, swagger_object_type, use_references, **kwargs
+    ):
+        SwaggerType, ChildSwaggerType = self._get_partial_types(
+            field, swagger_object_type, use_references, **kwargs
+        )
+
+        if (
+            isinstance(field, LengthHyperlinkedRelatedField)
+            and swagger_object_type == openapi.Schema
+        ):
+            max_length = field.max_length
+            min_length = field.min_length
+            return SwaggerType(
+                type=openapi.TYPE_STRING,
+                format=openapi.FORMAT_URI,
+                min_length=min_length,
+                max_length=max_length,
+                description=field.help_text,
+            )
+
+        return NotHandled
+
+
 class GegevensGroepInspector(FieldInspector):
     def process_result(self, result, method_name, obj, **kwargs):
         if not isinstance(result, openapi.Schema.OR_REF):
