@@ -1,17 +1,10 @@
-from .auth import (
-    AuthCheckMixin,
-    JWTAuthMixin,
-    JWTScopesMixin,
-    generate_jwt,
-    generate_jwt_auth,
-)
+from .auth import AuthCheckMixin, JWTAuthMixin, generate_jwt_auth
+from .caching import CacheMixin
 from .schema import TypeCheckMixin, get_operation_url, get_validation_errors
 from .urls import reverse, reverse_lazy
 
 __all__ = [
-    "generate_jwt",
     "AuthCheckMixin",
-    "JWTScopesMixin",
     "get_operation_url",
     "TypeCheckMixin",
     "get_validation_errors",
@@ -19,4 +12,5 @@ __all__ = [
     "reverse_lazy",
     "JWTAuthMixin",
     "generate_jwt_auth",
+    "CacheMixin",
 ]
